==> freeipa_3.3.4.orig.tar.gz: freeipa-3.3.4/ipatests/setup.py <==
#!/usr/bin/python
# Copyright (C) 2007  Red Hat
# see file 'COPYING' for use and warranty information
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""FreeIPA tests

FreeIPA is a server for identity, policy, and audit.
"""

DOCLINES = __doc__.split("\n")

import os
import sys
import distutils.sysconfig

CLASSIFIERS = """\
Development Status :: 4 - Beta
Intended Audience :: System Environment/Base
License :: GPL
Programming Language :: Python
Operating System :: POSIX
Operating System :: Unix
"""

# BEFORE importing distutils, remove MANIFEST. distutils doesn't properly
# update it when the contents of directories change.
if os.path.exists('MANIFEST'):
    os.remove('MANIFEST')

def setup_package():

    from distutils.core import setup

    old_path = os.getcwd()
    local_path = os.path.dirname(os.path.abspath(sys.argv[0]))
    os.chdir(local_path)
    sys.path.insert(0, local_path)

    try:
        setup(
            name = "ipatests",
            version = "3.3.4",
            license = "GPL",
            author = "FreeIPA Developers",
            author_email = "freeipa-devel@redhat.com",
            maintainer = "FreeIPA Developers",
            maintainer_email = "freeipa-devel@redhat.com",
            url = "http://www.freeipa.org/",
            description = DOCLINES[0],
            long_description = "\n".join(DOCLINES[2:]),
            download_url = "http://www.freeipa.org/page/Downloads",
            classifiers=filter(None, CLASSIFIERS.split('\n')),
            package_dir = {'ipatests': ''},
            packages = ["ipatests",
                        "ipatests.test_cmdline",
                        "ipatests.test_install",
                        "ipatests.test_integration",
                        "ipatests.test_ipalib",
                        "ipatests.test_ipapython",
                        "ipatests.test_ipaserver",
                        "ipatests.test_ipaserver.install",
                        "ipatests.test_pkcs10",
                        "ipatests.test_webui",
                        "ipatests.test_xmlrpc"],
            scripts=['ipa-run-tests', 'ipa-test-config', 'ipa-test-task'],
            package_data = {
                'ipatests.test_install': ['*.update'],
                'ipatests.test_integration': ['scripts/*'],
                'ipatests.test_pkcs10': ['*.csr']}
        )
    finally:
        del sys.path[0]
        os.chdir(old_path)
    return

if __name__ == '__main__':
    setup_package()

==> freeipa_4.0.5.orig.tar.gz: freeipa-4.0.5/ipatests/setup.py <==
#!/usr/bin/python2
# Copyright (C) 2007  Red Hat
# see file 'COPYING' for use and warranty information
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""FreeIPA tests

FreeIPA is a server for identity, policy, and audit.
"""

DOCLINES = __doc__.split("\n")

import os
import sys
import distutils.sysconfig

CLASSIFIERS = """\
Development Status :: 4 - Beta
Intended Audience :: System Environment/Base
License :: GPL
Programming Language :: Python
Operating System :: POSIX
Operating System :: Unix
"""

# BEFORE importing distutils, remove MANIFEST. distutils doesn't properly
# update it when the contents of directories change.
if os.path.exists('MANIFEST'):
    os.remove('MANIFEST')

def setup_package():

    from distutils.core import setup

    old_path = os.getcwd()
    local_path = os.path.dirname(os.path.abspath(sys.argv[0]))
    os.chdir(local_path)
    sys.path.insert(0, local_path)

    try:
        setup(
            name = "ipatests",
            version = "4.0.5",
            license = "GPL",
            author = "FreeIPA Developers",
            author_email = "freeipa-devel@redhat.com",
            maintainer = "FreeIPA Developers",
            maintainer_email = "freeipa-devel@redhat.com",
            url = "http://www.freeipa.org/",
            description = DOCLINES[0],
            long_description = "\n".join(DOCLINES[2:]),
            download_url = "http://www.freeipa.org/page/Downloads",
            classifiers=filter(None, CLASSIFIERS.split('\n')),
            package_dir = {'ipatests': ''},
            packages = ["ipatests",
                        "ipatests.test_cmdline",
                        "ipatests.test_install",
                        "ipatests.test_integration",
                        "ipatests.test_ipalib",
                        "ipatests.test_ipapython",
                        "ipatests.test_ipaserver",
                        "ipatests.test_ipaserver.test_install",
                        "ipatests.test_pkcs10",
                        "ipatests.test_webui",
                        "ipatests.test_xmlrpc"],
            scripts=['ipa-run-tests', 'ipa-test-config', 'ipa-test-task'],
            package_data = {
                'ipatests.test_install': ['*.update'],
                'ipatests.test_integration': ['scripts/*'],
                'ipatests.test_pkcs10': ['*.csr'],
                "ipatests.test_ipaserver": ['data/*'],
            }
        )
    finally:
        del sys.path[0]
        os.chdir(old_path)
    return

if __name__ == '__main__':
    setup_package()
